yakumo.glance.v2.image.Manager

Package yakumo :: Package glance :: Package v2 :: Module image :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

          object --+
                   |
        base.Manager --+
                       |
    base.GlanceV2Manager --+
                           |
                          Manager

manager class for images on Image V2 API

Nested Classes | [hide private]
| resource_class resource class for images on Image V2 API

Instance Methods | [hide private]
yakumo.glance.v2.image.Resource |
create(self, id=`'``__UNDEF__``'`, name=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`, tags=`'``__UNDEF__``'`, container_format=`'``__UNDEF__``'`, disk_format=`'``__UNDEF__``'`, min_disk=`'``__UNDEF__``'`, min_ram=`'``__UNDEF__``'`, is_protected=`'``__UNDEF__``'`, file=None, **kwargs) Register an image | source code
Inherited from `base.GlanceV2Manager`: `get` Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``image``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``image``'``
| _json_resources_key = ``'``images``'``
| _url_resource_path = ``'``/v2/images``'``
Inherited from `base.GlanceV2Manager` (private): `_has_extra_attr` Inherited from `base.Manager` (private): `_has_detail`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, id=`'``__UNDEF__``'`, name=`'``__UNDEF__``'`, is_public=`'``__UNDEF__``'`, tags=`'``__UNDEF__``'`, container_format=`'``__UNDEF__``'`, disk_format=`'``__UNDEF__``'`, min_disk=`'``__UNDEF__``'`, min_ram=`'``__UNDEF__``'`, is_protected=`'``__UNDEF__``'`, file=None, **kwargs) | source code
Register an image Non-standard key=value arguments are allowed (value must be a string). Parameters: `id` (str) - Image ID (optional) `name` (str) - Image name `is_public` (bool) - Public flag `tags` ([str]) - Tag list `container_format` (str) - Container format ('ami','ari','aki','bare',or 'ovf') `disk_format` (str) - Disk format ('ami','ari','aki','vhd','vmdk','raw','qcow2', 'vdi',or 'iso') `min_disk` (int) - Minimum disk size in GB `min_ram` (int) - Minimum RAM size in MB `is_protected` (bool) - Protected flag `file` (str) - Image file path Returns: yakumo.glance.v2.image.Resource Created image Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('name', 'name', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('file', 'file', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('disk_format',
        'disk_format',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('container_format',
        'container_format',
      ...